.main-graph[data-v-7095e488]{height:260px;padding-top:2px}.contributor-grid[data-v-7095e488]{display:grid;grid-template-columns:repeat(2,1fr);gap:1rem}.contributor-grid[data-v-7095e488]>*{min-width:0}@media (max-width: 991.98px){.contributor-grid[data-v-7095e488]{grid-template-columns:repeat(1,1fr)}}.contributor-name[data-v-7095e488]{margin-bottom:0}
