(self.webpackChunk=self.webpackChunk||[]).push([["pdfobject"],{"./node_modules/.pnpm/pdfobject@2.3.1/node_modules/pdfobject/pdfobject.js":(function(R,I){var w,j,F;(function(C,d){j=[],w=d,F=typeof w=="function"?w.apply(I,j):w,F!==void 0&&(R.exports=F)})(this,function(){"use strict";if(typeof window>"u"||window.navigator===void 0||window.navigator.userAgent===void 0)return!1;let C="2.3.1",d=window,f=d.navigator,v=f.userAgent,E=!1,O=function(){let e=d.chrome!==void 0,n=d.safari!==void 0||f.vendor!==void 0&&/Apple/.test(f.vendor)&&/Safari/.test(v),i=d.Mozilla!==void 0||/irefox/.test(v);return e||n||i},L=function(e){var n=null;try{n=new ActiveXObject(e)}catch{n=null}return!!n},U=function(){return"ActiveXObject"in d&&(L("AcroPDF.PDF")||L("PDF.PdfCtrl"))},A=function(){if(f.platform!==void 0&&f.platform==="MacIntel"&&f.maxTouchPoints!==void 0&&f.maxTouchPoints>1||/Mobi|Tablet|Android|iPad|iPhone/.test(v))return!1;let i=typeof f.pdfViewerEnabled=="boolean";return i&&!f.pdfViewerEnabled?!1:i&&f.pdfViewerEnabled||O()||U()}(),S=function(e){let n="",i,l=[],t="";if((e.comment||e.viewrect||e.highlight)&&(e.page||(e.page=1,g("The comment, viewrect, and highlight parameters require a page parameter, but none was specified. Defaulting to page 1."))),e.page&&(l.push("page="+encodeURIComponent(e.page)),delete e.page),e.fdf&&(t=e.fdf,delete e.fdf),e){for(i in e)e.hasOwnProperty(i)&&l.push(encodeURIComponent(i)+"="+encodeURIComponent(e[i]));t&&l.push("fdf="+encodeURIComponent(t)),n=l.join("&"),n&&(n="#"+n)}return n},g=function(e){return E||console.log("[PDFObject]",e),!1},B=function(e){for(;e.firstChild;)e.removeChild(e.firstChild)},N=function(e){let n=document.body;return typeof e=="string"?n=document.querySelector(e):d.jQuery!==void 0&&e instanceof jQuery&&e.length?n=e.get(0):e.nodeType!==void 0&&e.nodeType===1&&(n=e),n},H=function(e,n,i,l){if(window.Blob&&window.URL&&window.URL.createObjectURL){var t=new XMLHttpRequest;t.open("GET",e,!0),t.responseType="blob",t.onload=function(){if(t.status===200){var p=t.response,r=document.createElement("a");r.innerText="Download PDF",r.href=URL.createObjectURL(p),r.setAttribute("download",n),i.innerHTML=l.replace(/\[pdflink\]/g,r.outerHTML)}},t.send()}},k=function(e,n,i,l,t,p,r,y,h,s,b){B(n);let c=i;if(e==="pdfjs"){let a=b.indexOf("?")!==-1?"&":"?";c=b+a+"file="+encodeURIComponent(i)+l}else c+=l;let o=document.createElement("iframe");if(o.className="pdfobject",o.type="application/pdf",o.title=y,o.src=c,o.allow="fullscreen",o.frameborder="0",r&&(o.id=r),!h){let a="border: none;";n!==document.body?a+="width: "+t+"; height: "+p+";":a+="position: absolute; top: 0; right: 0; bottom: 0; left: 0; width: 100%; height: 100%;",o.style.cssText=a}let m=["className","type","title","src","style","id","allow","frameborder"];return s&&s.key&&m.indexOf(s.key)===-1&&o.setAttribute(s.key,typeof s.value<"u"?s.value:""),n.classList.add("pdfobject-container"),n.appendChild(o),n.getElementsByTagName("iframe")[0]},x=function(e,n,i){let l=n||!1,t=i||{};E=typeof t.suppressConsole=="boolean"?t.suppressConsole:!1;let p=typeof t.id=="string"?t.id:"",r=t.page||!1,y=t.pdfOpenParams||{},h=typeof t.fallbackLink=="string"||typeof t.fallbackLink=="boolean"?t.fallbackLink:!0,s=t.width||"100%",b=t.height||"100%",c=t.title||"Embedded PDF",o=typeof t.forcePDFJS=="boolean"?t.forcePDFJS:!1,m=typeof t.omitInlineStyles=="boolean"?t.omitInlineStyles:!1,a=t.PDFJS_URL||!1,u=N(l),D="",_=t.customAttribute||{},T=t.fallbackFileNameForBase64,M="<p>This browser does not support inline PDFs. Please download the PDF to view it: [pdflink]</p>";if(typeof e!="string")return g("URL is not valid");if(!u)return g("Target element cannot be determined");if(r&&(y.page=r),D=S(y),o&&a)return k("pdfjs",u,e,D,s,b,p,c,m,_,a);if(A)return k("iframe",u,e,D,s,b,p,c,m,_);if(a)return k("pdfjs",u,e,D,s,b,p,c,m,_,a);if(h)if(typeof h=="string")u.innerHTML=h.replace(/\[url\]/g,e);else{const P=e.match(/data:application\/pdf;(?:.*filename=([^;]+);)?.*base64,/i);if(P)T=T||P[1]||"file.pdf",H(e,T,u,M);else{let X="<a href='"+e+"'>Download PDF</a>";u.innerHTML=M.replace(/\[pdflink\]/g,X)}}return g("This browser does not support embedded PDFs")};return{embed:function(e,n,i){return x(e,n,i)},pdfobjectversion:(function(){return C})(),supportsPDFs:(function(){return A})()}})})}]);
