"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["node_modules_pnpm_mermaid-js_parser_0_6_2_node_modules_mermaid-js_parser_dist_chunks_mermaid--410de4"],{"./node_modules/.pnpm/@mermaid-js+parser@0.6.2/node_modules/@mermaid-js/parser/dist/chunks/mermaid-parser.core/architecture-O4VJ6CD3.mjs":(function(m,s,e){e.d(s,{createArchitectureServices:function(){return r.S}});var r=e("./node_modules/.pnpm/@mermaid-js+parser@0.6.2/node_modules/@mermaid-js/parser/dist/chunks/mermaid-parser.core/chunk-JEIROHC2.mjs"),_=e("./node_modules/.pnpm/@mermaid-js+parser@0.6.2/node_modules/@mermaid-js/parser/dist/chunks/mermaid-parser.core/chunk-4KMFLZZN.mjs")})}]);
